﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Steema.TeeChart;
using Steema.TeeChart.Styles;

namespace Microseconds
{
	public partial class Form1 : Form
	{
		// One Tick is 100 ns
		private static readonly long _ticksPerDay = 24 * 60 * 60 * 10000000L;

		public Form1()
		{
			InitializeComponent();

			InitMicrosecond();
			InitOADate();
		}

		private void InitMicrosecond()
		{
			Points points = new Points();

			double microsecond = 10.0 / _ticksPerDay;

			for (int i = 0; i < 50; i++)
				points.Add(40906.75 + i * microsecond, i);

			points.Pointer.Style = Steema.TeeChart.Styles.PointerStyles.Triangle;
			points.XValues.DateTime = true;

			chart1.Series.Add(points);
			chart1.Header.Text = "Space unequally distributed";

			Axis axis = chart1.Axes.Bottom;
			axis.Increment = Utils.GetDateTimeStep(DateTimeSteps.OneMicrosecond);
			axis.Labels.DateTimeFormat = "dd.MM.yyyy\nHH:mm:ss.ffffff";
		}

		private void InitOADate()
		{
			Points points1 = new Points();
			Points points2 = new Points();

			DateTime now = DateTime.Now;
			for (int i = 0; i < 100; i++)
			{
				points1.Add(ToOADate(now), i);
				points2.Add(now, i);
				//points2.Add(now.ToOADate(), i); // produces the same result as statement above
				now = now.AddTicks(500); // Add 50 us
			}
			points1.Pointer.Style = Steema.TeeChart.Styles.PointerStyles.Triangle;
			points1.XValues.DateTime = true;
			points1.Title = "Custom ToOADate()";

			points2.Pointer.Style = Steema.TeeChart.Styles.PointerStyles.Circle;
			points2.XValues.DateTime = true;
			points2.Title = "Standard ToOADate()";

			chart2.Series.Add(points2);
			chart2.Series.Add(points1);
			chart2.Header.Text = "Rounded";

			Axis axis = chart2.Axes.Bottom;
			axis.Increment = Utils.GetDateTimeStep(DateTimeSteps.OneMicrosecond);
			axis.Labels.DateTimeFormat = "dd.MM.yyyy\nHH:mm:ss.ffffff";

		}

		private double ToOADate(DateTime original)
		{
			// Convert Time within the day to OADate
			double oaDate = 1.0 / _ticksPerDay * (original.Ticks % _ticksPerDay);
			// Convert day to OADate
			oaDate += Math.Floor(original.ToOADate());
			return oaDate;
		}
	}
}
